@@ -3,7 +3,7 @@ use 5.008_001;
 use strict;
 use warnings;
 use parent qw(Plack::Middleware);
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Encode;
 use File::ShareDir;
@@ -332,7 +332,7 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN site
 near you. Or see L<http://search.cpan.org/dist/Plack-Middleware-Debug/>.
 
 The development version lives at
-L<http://github.com/hanekomu/plack-middleware-debug/>. Instead of sending
+L<http://github.com/miyagawa/plack-middleware-debug/>. Instead of sending
 patches, please fork this project using the standard git and github
 infrastructure.
 
